@@ -15,10 +15,10 @@ ddelap <- function(x, alpha, beta, lambda, log = FALSE) {
 pdelap <- function(q, alpha, beta, lambda, lower.tail = TRUE, log.p = FALSE) {
   # These interrupts throw errors even using expect_error. Excluding for now
   # nocov start
-  if (any(q[is.finite(q)] >= 2^63)) {
-    stop("Function cannot handle values >= 2^63")
+  if (any(q[is.finite(q)] >= 2 ^ 63)) {
+    stop("Function cannot handle values >= 2^63.")
   }
-  if (any(q[is.finite(q)] >= 2^15)) {
+  if (any(q[is.finite(q)] >= 2 ^ 15)) {
     cat("There are values >= 32768.",
         "This may take minutes if not hours to compute. Are you sure?\n")
     resp <- readline("Press 'y' to continue.\n")
@@ -45,34 +45,30 @@ qdelap <- function(p, alpha, beta, lambda, lower.tail = TRUE, log.p = FALSE,
   if (exact) {
     QDLAP <- .Call(qdelap_C, p, alpha, beta, lambda, lt_f, lp_f,
                    getDelapThreads())
-  } else {
-    if (length(alpha) > 1L || length(beta) > 1L || length(lambda) > 1L ||
+  } else if (length(alpha) > 1L || length(beta) > 1L || length(lambda) > 1L ||
           anyNA(p)) {
-      warning("Quantile approximation relies on pooling and is not accurate ",
-              "when passed vector-valued parameters, NaNs, or NAs. Using ",
-              "exact version instead.")
-      QDLAP <- .Call(qdelap_C, p, alpha, beta, lambda, lt_f, lp_f,
-                     getDelapThreads())
-    } else {
-      if (alpha <= 0 || beta <= 0 || lambda <= 0) {
-        QDLAP <- rep.int(NaN, length(p))
-      } else {
-        if (log.p) p <- exp(p)
-        if (!lower.tail) p <- 1 - p
-        pValid <- p[p > 0 & p < 1]
-        pNeg <- p[p < 0]
-        p0 <- p[p == 0]
-        pInf <- p[p >= 1]
-        n <- min(10 ^ (ceiling(log(alpha * beta + lambda, 10)) + 5), 1e7)
-        shiftedGammas <- rgamma(n, shape = alpha, scale = beta)
-        DP <- rpois(n, lambda = (shiftedGammas + lambda))
-        qValid <- as.vector(quantile(DP, pValid, na.rm = TRUE, type = 8))
-        qNeg <- rep.int(NaN, times = length(pNeg))
-        q0 <- rep.int(0, times = length(p0))
-        qInf <- rep.int(Inf, times = length(pInf))
-        QDLAP <- as.vector(c(qNeg, q0, qValid, qInf), mode = "double")
-      }
-    }
+    warning("Quantile approximation relies on pooling and is not accurate when",
+            " passed vector-valued parameters, NaNs, or NAs. Using exact",
+            " version instead.")
+    QDLAP <- .Call(qdelap_C, p, alpha, beta, lambda, lt_f, lp_f,
+                   getDelapThreads())
+  } else if (alpha <= 0 || beta <= 0 || lambda <= 0) {
+    QDLAP <- rep.int(NaN, length(p))
+  } else {
+      if (log.p) p <- exp(p)
+      if (!lower.tail) p <- 1 - p
+      pValid <- p[p > 0 & p < 1]
+      pNeg <- p[p < 0]
+      p0 <- p[p == 0]
+      pInf <- p[p >= 1]
+      n <- min(10 ^ (ceiling(log(alpha * beta + lambda, 10)) + 5), 1e7)
+      shiftedGammas <- rgamma(n, shape = alpha, scale = beta)
+      DP <- rpois(n, lambda = (shiftedGammas + lambda))
+      qValid <- as.vector(quantile(DP, pValid, na.rm = TRUE, type = 8))
+      qNeg <- rep.int(NaN, times = length(pNeg))
+      q0 <- rep.int(0, times = length(p0))
+      qInf <- rep.int(Inf, times = length(pInf))
+      QDLAP <- as.vector(c(qNeg, q0, qValid, qInf), mode = "double")
   }
   if (any(is.nan(QDLAP))) warning("NaNs produced")
   return(QDLAP)
@@ -88,13 +84,11 @@ rdelap <- function(n, alpha, beta, lambda, exact = TRUE) {
   lambda <- as.double(lambda)
   if (exact) {
     RDLAP <- .Call(rdelap_C, n, alpha, beta, lambda, getDelapThreads())
-  } else {
-    if (any(alpha <= 0) || any(beta <= 0) || any(lambda <= 0)) {
+  } else if (any(alpha <= 0) || any(beta <= 0) || any(lambda <= 0)) {
       RDLAP <- (rep.int(NaN, n))
-    } else {
-      shiftedGammas <- rgamma(n, shape = alpha, scale = beta)
-      RDLAP <- rpois(n, lambda = (shiftedGammas + lambda))
-    }
+  } else {
+    shiftedGammas <- rgamma(n, shape = alpha, scale = beta)
+    RDLAP <- rpois(n, lambda = (shiftedGammas + lambda))
   }
   if (any(is.nan(RDLAP))) warning("NaNs produced")
   return(RDLAP)
